wallaroo.wallaroo_ml_ops_api_client.models.assays_create_json_body_baseline_type_2_sliding API documentation

# wallaroo.wallaroo_ml_ops_api_client.models.assays_create_json_body_baseline_type_2_sliding

View Source

     1from typing import Any, Dict, List, Type, TypeVar
     2
     3import attr
     4
     5T = TypeVar("T", bound="AssaysCreateJsonBodyBaselineType2Sliding")
     6
     7@attr.s(auto_attribs=True)
     8class AssaysCreateJsonBodyBaselineType2Sliding:
     9    """
    10    Attributes:
    11        pipeline (str):
    12        model (str):
    13        width (str):
    14        offset (str):
    15    """
    16
    17    pipeline: str
    18    model: str
    19    width: str
    20    offset: str
    21    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
    22
    23
    24    def to_dict(self) -> Dict[str, Any]:
    25        pipeline = self.pipeline
    26        model = self.model
    27        width = self.width
    28        offset = self.offset
    29
    30        field_dict: Dict[str, Any] = {}
    31        field_dict.update(self.additional_properties)
    32        field_dict.update({
    33            "pipeline": pipeline,
    34            "model": model,
    35            "width": width,
    36            "offset": offset,
    37        })
    38
    39        return field_dict
    40
    41
    42
    43    @classmethod
    44    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    45        d = src_dict.copy()
    46        pipeline = d.pop("pipeline")
    47
    48        model = d.pop("model")
    49
    50        width = d.pop("width")
    51
    52        offset = d.pop("offset")
    53
    54        assays_create_json_body_baseline_type_2_sliding = cls(
    55            pipeline=pipeline,
    56            model=model,
    57            width=width,
    58            offset=offset,
    59        )
    60
    61        assays_create_json_body_baseline_type_2_sliding.additional_properties = d
    62        return assays_create_json_body_baseline_type_2_sliding
    63
    64    @property
    65    def additional_keys(self) -> List[str]:
    66        return list(self.additional_properties.keys())
    67
    68    def __getitem__(self, key: str) -> Any:
    69        return self.additional_properties[key]
    70
    71    def __setitem__(self, key: str, value: Any) -> None:
    72        self.additional_properties[key] = value
    73
    74    def __delitem__(self, key: str) -> None:
    75        del self.additional_properties[key]
    76
    77    def __contains__(self, key: str) -> bool:
    78        return key in self.additional_properties

@attr.s(auto_attribs=True)
class AssaysCreateJsonBodyBaselineType2Sliding: View Source

     8@attr.s(auto_attribs=True)
     9class AssaysCreateJsonBodyBaselineType2Sliding:
    10    """
    11    Attributes:
    12        pipeline (str):
    13        model (str):
    14        width (str):
    15        offset (str):
    16    """
    17
    18    pipeline: str
    19    model: str
    20    width: str
    21    offset: str
    22    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
    23
    24
    25    def to_dict(self) -> Dict[str, Any]:
    26        pipeline = self.pipeline
    27        model = self.model
    28        width = self.width
    29        offset = self.offset
    30
    31        field_dict: Dict[str, Any] = {}
    32        field_dict.update(self.additional_properties)
    33        field_dict.update({
    34            "pipeline": pipeline,
    35            "model": model,
    36            "width": width,
    37            "offset": offset,
    38        })
    39
    40        return field_dict
    41
    42
    43
    44    @classmethod
    45    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    46        d = src_dict.copy()
    47        pipeline = d.pop("pipeline")
    48
    49        model = d.pop("model")
    50
    51        width = d.pop("width")
    52
    53        offset = d.pop("offset")
    54
    55        assays_create_json_body_baseline_type_2_sliding = cls(
    56            pipeline=pipeline,
    57            model=model,
    58            width=width,
    59            offset=offset,
    60        )
    61
    62        assays_create_json_body_baseline_type_2_sliding.additional_properties = d
    63        return assays_create_json_body_baseline_type_2_sliding
    64
    65    @property
    66    def additional_keys(self) -> List[str]:
    67        return list(self.additional_properties.keys())
    68
    69    def __getitem__(self, key: str) -> Any:
    70        return self.additional_properties[key]
    71
    72    def __setitem__(self, key: str, value: Any) -> None:
    73        self.additional_properties[key] = value
    74
    75    def __delitem__(self, key: str) -> None:
    76        del self.additional_properties[key]
    77
    78    def __contains__(self, key: str) -> bool:
    79        return key in self.additional_properties

Attributes: pipeline (str): model (str): width (str): offset (str):

AssaysCreateJsonBodyBaselineType2Sliding(pipeline: str, model: str, width: str, offset: str) View Source

    2def __init__(self, pipeline, model, width, offset):
    3    self.pipeline = pipeline
    4    self.model = model
    5    self.width = width
    6    self.offset = offset
    7    self.additional_properties = __attr_factory_additional_properties()

Method generated by attrs for class AssaysCreateJsonBodyBaselineType2Sliding.

def to_dict(self) -> Dict[str, Any]: View Source

    25    def to_dict(self) -> Dict[str, Any]:
    26        pipeline = self.pipeline
    27        model = self.model
    28        width = self.width
    29        offset = self.offset
    30
    31        field_dict: Dict[str, Any] = {}
    32        field_dict.update(self.additional_properties)
    33        field_dict.update({
    34            "pipeline": pipeline,
    35            "model": model,
    36            "width": width,
    37            "offset": offset,
    38        })
    39
    40        return field_dict

@classmethod
def from_dict(cls: Type[~T], src_dict: Dict[str, Any]) -> ~T: View Source

    44    @classmethod
    45    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    46        d = src_dict.copy()
    47        pipeline = d.pop("pipeline")
    48
    49        model = d.pop("model")
    50
    51        width = d.pop("width")
    52
    53        offset = d.pop("offset")
    54
    55        assays_create_json_body_baseline_type_2_sliding = cls(
    56            pipeline=pipeline,
    57            model=model,
    58            width=width,
    59            offset=offset,
    60        )
    61
    62        assays_create_json_body_baseline_type_2_sliding.additional_properties = d
    63        return assays_create_json_body_baseline_type_2_sliding

additional_keys: List[str]